@@ -22,10 +22,10 @@ from preggy import create_assertions
 def to_equal(topic, expected):
     '''Asserts that `topic == expected`.'''
 
-    if isinstance(topic, six.string_types + (six.binary_type, )):
-        topic = six.b(topic)
+    if isinstance(topic, (six.binary_type, )):
+        topic = topic.encode('utf-8')
 
-    if isinstance(expected, six.string_types + (six.binary_type, )):
-        expected = six.b(expected)
+    if isinstance(expected, (six.binary_type, )):
+        expected = expected.encode('utf-8')
 
     return expected == topic
