@@ -1,6 +1,5 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-'''preggy like assertions.  For use with `expect()` (see `preggy.core`).
+'''preggy 'like' assertions.  For use with `expect()` (see `preggy.core`).
 '''
 
 
@@ -14,7 +13,7 @@
 try:
     from six import string_types, binary_type
 except ImportError:
-    print ("Ignoring six. Probably setup.py installing package.")
+    print("Ignoring six. Probably setup.py installing package.")
 
 import numbers
 
@@ -23,18 +22,12 @@ from preggy import create_assertions
 
 @create_assertions
 def to_be_like(topic, expected):
-    '''Asserts that `topic` is like (similar to) `expected`. Allows
-    some leeway.
-
-    '''
+    '''Asserts that `topic` is like (similar to) `expected`. Allows some leeway.'''
     return match_alike(expected, topic)
 
 
 def match_alike(expected, topic):
-    '''Asserts the "like"-ness of `topic` and `expected` according
-    to their types.
-
-    '''
+    '''Asserts the "like"-ness of `topic` and `expected` according to their types.'''
     if topic is None:
         return expected is None
 
